@@ -20,3 +20,8 @@ from .is_int import *
 from .is_number import *
 from .is_ean import *
 from .is_uuid import *
+from .is_isrc import *
+from .is_jwt import *
+from .is_md5 import *
+from .is_port import *
+from .is_ip import *
